@@ -1,41 +1,26 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
-    Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2012-2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef NETWORKMANAGERQT_CONNECTION_SETTINGS_H
 #define NETWORKMANAGERQT_CONNECTION_SETTINGS_H
 
-#include <networkmanagerqt/networkmanagerqt_export.h>
 #include "setting.h"
+#include <networkmanagerqt/networkmanagerqt_export.h>
 
 #undef signals
 #include <libnm/NetworkManager.h>
 #define signals Q_SIGNALS
 
-#include <QString>
 #include <QDateTime>
 #include <QHash>
+#include <QString>
 
 namespace NetworkManager
 {
-
 class ConnectionSettingsPrivate;
 
 /**
@@ -66,13 +51,14 @@ public:
         Team,
         Generic,
         Tun,
-        IpTunnel
+        IpTunnel,
+        WireGuard,
     };
 
     enum AutoconnectSlaves {
         SlavesDefault = -1,
         DoNotConnectSlaves = 0,
-        ConnectAllSlaves = 1
+        ConnectAllSlaves = 1,
     };
 
     enum Lldp {
@@ -88,10 +74,9 @@ public:
         MeteredYes = 1,
         MeteredNo = 2,
         MeteredGuessYes = 3,
-        MeteredGuessNo = 4
+        MeteredGuessNo = 4,
     };
 
-
     static ConnectionType typeFromString(const QString &typeString);
     static QString typeAsString(const ConnectionType type);
     static QString createNewUuid();
